@@ -274,4 +274,11 @@ class ServiceDO(BaseDO):
     external_ip: Optional[str]
     port_info: str
     age: str
+    _life_time: int=5
+
+@dataclass
+class PodContainerDO(BaseDO):
+    pod_name: str
+    init_container_info: str
+    container_info: str
     _life_time: int=5
\ No newline at end of file
