@@ -12,6 +12,7 @@ from .converter import(
     InstanceInfoConverter,
     InstanceTypeWithStatusConverter,
     NodeInfoConverter,
+    PodContainerConverter,
 )
 from ..domain.repository import(
     K3SRepository,
@@ -76,6 +77,7 @@ deployment_converter = DeploymentConverter()
 namespace_converter = NamespaceConverter()
 node_meta_converter = NodeMetaConverter()
 pod_converter = PodConverter()
+pod_container_converter = PodContainerConverter()
 secret_converter = SecretConverter()
 pod_oss_operation_info_converter = PodOSSOperationInfoConverter()
 ingress_converter = IngressConverter()
@@ -342,6 +344,26 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
             namespace_name=namespace_name
         )
 
+    def _get_pod_containers(self, cluster_name: Name, namespace_name: Name)->Optional[List[Pod]]:
+        cluster_name = cluster_name.get_value()
+        namespace_name = namespace_name.get_value()
+        result = self.ao.get_pod_containers(cluster_name, namespace_name)
+        if result.succeed:
+            return [pod_container_converter.to_entity(x) for x in result.get_value()]
+        else:
+            self.log_func(result.error_traceback)
+            return None
+
+    def get_pod_containers(self, cluster_name: Name, namespace_name: Name)->Optional[List[Pod]]:
+        key = f'{cluster_name.get_value()}:{namespace_name.get_value()}:pod_containers'
+        return self.find_entity_helper(
+            self._get_pod_containers,
+            key=key,
+            converter=None,
+            cluster_name=cluster_name,
+            namespace_name=namespace_name
+        )
+
     def _get_secrets(self, cluster_name: Name, namespace_name: Name)->Optional[List[Secret]]:
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
